@@ -12,8 +12,10 @@ import math
 package_root = os.path.dirname(os.path.abspath(__file__))
 
 def limtozero(x):
+
     if x < 1e-15:
         x = 0
+
     return x
 
 def get_affine(file_name):
@@ -36,6 +38,7 @@ def fwe_correct(p, size=[60, 60, 60], n=64):
 
     nq = 1
     ni = 1
+
     while nq < n:
         ni = ni + 1
         nq = ni*ni*ni
@@ -50,7 +53,7 @@ def fwe_correct(p, size=[60, 60, 60], n=64):
 
     return fwep
 
-def fdr_correct(p, size=[60, 60, 60], n=64):
+def fdr_correct(p, size=[60, 60, 60], n=64, type="sphere"):
 
     x = size[0]
     y = size[1]
@@ -60,44 +63,115 @@ def fdr_correct(p, size=[60, 60, 60], n=64):
     py = np.shape(p)[1]
     pz = np.shape(p)[2]
 
-    n = float(n*px*py*pz/(x*y*z))
+    if type == "cube":
 
-    nq = 1
-    ni = 1
-    while nq < n:
-        ni = ni + 1
-        nq = ni*ni*ni
+        n = float(n*px*py*pz/(x*y*z))
 
-    n = nq
+        nq = 1
+        ni = 1
 
-    print(n, ni)
+        while nq < n:
+            ni = ni + 1
+            nq = ni*ni*ni
 
-    fdrp = np.full([px, py, pz], np.nan)
+        n = nq
 
-    for i in range(px-ni+1):
-        for j in range(py-ni+1):
-            for k in range(pz-ni+1):
+        print(n, ni)
 
-                pcluster = p[i:i+ni, j:j+ni, k:k+ni]
-                pcluster = np.reshape(pcluster, [n])
+        fdrp = np.full([px, py, pz], np.nan)
 
-                index = np.argsort(pcluster)
-                for l in range(n):
-                    pcluster[l] = float(pcluster[l]*n/(l+1))
+        for i in range(px-ni+1):
+            for j in range(py-ni+1):
+                for k in range(pz-ni+1):
 
-                for l in range(n-1):
-                    if pcluster[-l-1] < pcluster[-l-2]:
-                        pcluster[-l-2] = pcluster[-l-1]
+                    pcluster = p[i:i+ni, j:j+ni, k:k+ni]
+                    pcluster = np.reshape(pcluster, [n])
 
-                newpcluster = np.full([n], np.nan)
-                for l in range(n):
-                    newpcluster[l] = pcluster[index[l]]
+                    index = np.argsort(pcluster)
 
-                fdrp[i:i+ni, j:j+ni, k:k+ni] = np.reshape(newpcluster, [ni, ni, ni])
+                    for l in range(n):
+                        pcluster[index[l]] = float(pcluster[index[l]]*n/(l+1))
 
-    print("finished FDR correct")
+                    for l in range(n-1):
+                        if pcluster[index[-l-1]] < pcluster[index[-l-2]]:
+                            pcluster[index[-l-2]] = pcluster[index[-l-1]]
+
+                    newpcluster = np.full([n], np.nan)
+
+                    for l in range(n):
+                        newpcluster[l] = pcluster[index[l]]
+
+                    fdrp[i:i+ni, j:j+ni, k:k+ni] = np.reshape(newpcluster, [ni, ni, ni])
+
+        print("finished FDR correct")
+
+        return fdrp
+
+    elif type == "sphere":
+
+        ni = int(nr * px * py * pz / (x * y * z)) + 1
+
+        c0 = [int(ni), int(ni), int(ni)]
+        n0 = 0
+        for i in range(int(2 * ni + 1)):
+            for j in range(int(2 * ni + 1)):
+                for k in range(int(2 * ni + 1)):
+                    dist = np.square(i - c0[0]) + np.square(j - c0[1]) + np.square(k - c0[2])
+                    if dist <= ni * ni:
+                        # print(i, j)
+                        n0 = n0 + 1
+
+        n = n0
+        # print(c0)
+        # print(n0)
+        print(n, ni)
+
+        fdrp = np.full([px, py, pz], np.nan)
+
+        for i in range(px - 2 * ni):
+            for j in range(py - 2 * ni):
+                for k in range(pz - 2 * ni):
+
+                    nindex = 0
+
+                    pcluster = np.zeros([n], dtype=np.float)
+
+                    for lx in range(2 * ni + 1):
+                        for ly in range(2 * ni + 1):
+                            for lz in range(2 * ni + 1):
+                                dist = np.square(lx - c0[0]) + np.square(ly - c0[1]) + np.square(lz - c0[2])
+                                if dist <= ni * ni:
+                                    pcluster[nindex] = p[i + lx, j + ly, k + lz]
+                                    nindex = nindex + 1
+
+                    index = np.argsort(pcluster)
+
+                    for l in range(n):
+                        pcluster[index[l]] = float(pcluster[index[l]] * n / (l + 1))
+
+                    for l in range(n - 1):
+                        if pcluster[index[-l - 1]] < pcluster[index[-l - 2]]:
+                            pcluster[index[-l - 2]] = pcluster[index[-l - 1]]
+
+                    newpcluster = np.full([n], np.nan)
+
+                    for l in range(n):
+                        newpcluster[l] = pcluster[index[l]]
+
+                    nindex = 0
+
+                    for lx in range(2 * ni + 1):
+                        for ly in range(2 * ni + 1):
+                            for lz in range(2 * ni + 1):
+                                dist = np.square(lx - c0[0]) + np.square(ly - c0[1]) + np.square(lz - c0[2])
+                                if dist <= ni * ni:
+                                    fdrp[i + lx, j + ly, k + lz] = newpcluster[nindex]
+                                    nindex = nindex + 1
+
+        print("finished FDR correct")
+
+        return fdrp
 
-    return fdrp
 
 def correct_by_threshold(img, threshold):
 
@@ -106,6 +180,7 @@ def correct_by_threshold(img, threshold):
     sz = np.shape(img)[2]
 
     nsmall = 1
+
     while nsmall*nsmall*nsmall < threshold:
         nsmall = nsmall + 1
 
@@ -117,26 +192,38 @@ def correct_by_threshold(img, threshold):
 
                 listlarge = list(np.reshape(img[i:i+nlarge, j:j+nlarge, k:k+nlarge], [nlarge*nlarge*nlarge]))
                 print(listlarge.count(0))
+
                 if listlarge.count(0) < nlarge*nlarge*nlarge:
+
                     index1 = 0
+
                     for l in range(nlarge):
                         for m in range(nlarge):
+
                             if img[i + l, j + m, k] == 0:
                                 index1 = index1 + 1
+
                             if img[i + l, j + m, k + nlarge - 1] == 0:
                                 index1 = index1 + 1
+
                     for l in range(nlarge-1):
                         for m in range(nlarge-2):
+
                             if img[i + l, j, k + m] == 0:
                                 index1 = index1 + 1
+
                             if img[i, j + l + 1, k + m] == 0:
                                 index1 = index1 + 1
+
                             if img[i + nlarge - 1, j + l, k + m] == 0:
                                 index1 = index1 + 1
+
                             if img[i + l + 1, j + nlarge - 1, k + m] == 0:
                                 index1 = index1 + 1
+
                     nex = nlarge * nlarge * nlarge - nsmall * nsmall * nsmall
                     print("index1:"+str(index1))
+
                     if index1 == nex:
                         print("**************************")
                         unit = img[i+1:i+1+nsmall, j+1:j+1+nsmall, k+1:k+1+nsmall]
@@ -144,8 +231,10 @@ def correct_by_threshold(img, threshold):
                         list_internal = list(unit)
                         index2 = nsmall*nsmall*nsmall-list_internal.count(0)
                         print(index1, index2)
+
                         if index2 < threshold:
                             img[i+1:i+1+nsmall, j]
+
                             for l in range(nsmall):
                                 for m in range(nsmall):
                                     for p in range(nsmall):
